@@ -11,11 +11,11 @@
 ;;;; in Text, HTML, and XML formats. This includes hyperlinking
 ;;;; capability and sub-objects.
 ;;;;
-;;;; $Id: mop.lisp 8216 2003-11-16 02:57:17Z kevin $
+;;;; $Id: mop.lisp 11039 2006-08-18 07:45:31Z kevin $
 ;;;;
 ;;;; This file is Copyright (c) 2000-2003 by Kevin M. Rosenberg
 ;;;; *************************************************************************
- 
+
 (in-package #:hyperobject)
 
 ;; Main class
@@ -47,7 +47,7 @@
 
    ;;; The remainder of these fields are calculated one time
    ;;; in finalize-inheritence.
-   
+
    (subobjects :initform nil :accessor subobjects
 	       :documentation
 	       "List of fields that contain a list of subobjects objects.")
@@ -66,7 +66,7 @@
 		 :documentation "The default view for a class")
    (documementation :initform nil :initarg :documentation
 		    :documentation "Documentation string for hyperclass.")
-   
+
    ;; SQL commands
    (create-table-cmd :initform nil :reader create-table-cmd)
    (create-indices-cmds :initform nil :reader create-index-cmds)
@@ -116,7 +116,7 @@
   #+ignore
   (unless (find-class (class-name cl))
     (setf (find-class (class-name cl)) cl))
-  
+
   (init-hyperobject-class cl)
   )
 
@@ -126,13 +126,13 @@
 		      'compute-effective-slot-definition)))
 	    3)
     (pushnew :ho-normal-cesd cl:*features*))
-  
+
     (when (>= (length (generic-function-lambda-list
 		       (ensure-generic-function
 			'direct-slot-definition-class)))
 	    3)
       (pushnew :ho-normal-dsdc cl:*features*))
-    
+
     (when (>= (length (generic-function-lambda-list
 		       (ensure-generic-function
 			'effective-slot-definition-class)))
@@ -144,7 +144,7 @@
 					 #+ho-normal-dsdc &rest iargs)
   (find-class 'hyperobject-dsd))
 
-(defmethod effective-slot-definition-class ((cl hyperobject-class) 
+(defmethod effective-slot-definition-class ((cl hyperobject-class)
 					    #+ho-normal-esdc &rest iargs)
   (find-class 'hyperobject-esd))
 
@@ -175,7 +175,7 @@
     #-lispworks
     (declare (ignore slot-name))
     )
-  
+
   (dolist (option *class-options*)
     (eval `(process-class-option ,option)))
   (dolist (option *slot-options*)
@@ -233,6 +233,23 @@
     (t
      t)))
 
+(defmethod initialize-instance :around ((obj hyperobject-dsd) &rest initargs)
+  (do* ((saved-initargs initargs)
+        (parsed (list obj))
+        (name (first initargs) (first initargs))
+        (val (second initargs) (second initargs)))
+      ((null initargs)
+       (apply #'call-next-method parsed))
+    (if (eql name :value-type)
+        (progn
+          (setq val (canonicalize-value-type val))
+          (setq parsed (append parsed (list name val)))
+          (setq parsed (append parsed (list :type
+                                            (value-type-to-lisp-type
+                                             (canonicalize-value-type val))))))
+      (setq parsed (append parsed (list name val))))
+    (setq initargs (cddr initargs))))
+  
 (defmethod compute-effective-slot-definition :around ((cl hyperobject-class)
 						      #+ho-normal-cesd name
 						      dsds)
@@ -243,14 +260,11 @@
 	esd)))
 
 (defun compute-hyperobject-esd (esd dsds)
-  (let* ((dsd (car dsds))
-	 (value-type (canonicalize-value-type (slot-value dsd 'value-type))))
-    (multiple-value-bind (sql-type sql-length) 
-	(value-type-to-sql-type value-type)
+  (let* ((dsd (car dsds)))
+    (multiple-value-bind (sql-type sql-length)
+	(value-type-to-sql-type (dsd-value-type dsd))
       (setf (esd-sql-type esd) sql-type)
       (setf (esd-sql-length esd) sql-length))
-    (setf (slot-value esd 'type) (value-type-to-lisp-type value-type))
-    (setf (esd-value-type esd) value-type)
     (setf (esd-user-name esd)
 	  (aif (dsd-user-name dsd)
 	       it
@@ -263,7 +277,8 @@
 	  (aif (dsd-sql-name dsd)
 	       it
 	       (lisp-name-to-sql-name (slot-definition-name dsd))))
-    (dolist (name '(print-formatter subobject hyperlink hyperlink-parameters
+    (dolist (name '(value-type print-formatter subobject hyperlink
+                    hyperlink-parameters
 		    description value-constraint indexed null-allowed
 		    unique short-description void-text read-only-groups
 		    hidden-groups unit disable-predicate view-type
@@ -379,7 +394,7 @@ SQL name"
 ;; The reader is a function and the reader-keys are slot names.  The slot is lazily set to
 ;; the result of applying the function to the slot-values of those slots, and that value
 ;; is also returned.
-(defun ensure-lazy-reader (cl class-name slot-name subobj-class reader 
+(defun ensure-lazy-reader (cl class-name slot-name subobj-class reader
 			   &rest reader-keys)
   (setf (getf (gethash cl *lazy-readers*) slot-name)
     (aif subobj-class
@@ -425,7 +440,7 @@ SQL name"
   "Make sure all class slots have an expected value"
   (unless (user-name cl)
     (setf (user-name cl) (format nil "~:(~A~)" (class-name cl))))
-  
+
   (setf (user-name-plural cl)
 	(if (and (consp (user-name cl)) (cadr (user-name cl)))
 	    (cadr (user-name cl))
@@ -440,7 +455,7 @@ SQL name"
 	     (if (listp it)
 		 (car it)
 	       it))))
-  
+
   (unless (sql-name cl)
     (setf (sql-name cl) (lisp-name-to-sql-name (class-name cl))))
   )
